
Imports DotNetNuke
Imports System.Data.SqlClient

Namespace VinoCellar.Modules.VCLinks
    Partial Class ucAddLink
        Inherits Entities.Modules.PortalModuleBase

#Region " Private Members "

        Private VCLinksID As Integer
        Private intUserID As Integer

#End Region

#Region " Private Methods "

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try
                bReturn.Attributes.Add("onclick", "history.back()")
                bDelete.Attributes.Add("onclick", "return confirm('Are you sure you want to delete this link?');")


                If Page.IsPostBack = False Then
                    ReadQueryString()
                    'Use normal "addlink" functionality if LinkID equals zero
                    If VCLinksID = 0 Then
                        'Make sure user is registered
                        CheckPermissions()
                        PopulateCat()
                        bSubmit.Visible = "True"
                        bDelete.Visible = "False"
                        bUpdate.Visible = "False"
                    End If
                    'Use "editlink" functionality if LinkID is supplied
                    If VCLinksID > 0 Then
                        'Since there is a linkid, we'll populate all fields
                        PopulateCat()
                        PopulateFields()
                        'See if user really has edit permission
                        CheckEditPermissions()

                    End If
                End If

            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub ReadQueryString()
            If (Request("LinkID") <> "") Then
                If (IsNumeric(Request("LinkID"))) Then
                    VCLinksID = CInt(Request.QueryString("LinkID"))
                End If
            Else
                VCLinksID = Null.NullInteger
            End If
        End Sub

        Private Sub CheckPermissions()
            'If UserID = -1 then user is anonymous and not logged in
            If Me.UserId = -1 Then
                lblPermission.Visible = "true"
                lblPermission.Text = "   * You must be a registered user to Add a Wine Link<br />"
                bSubmit.Enabled = "False"
                bSubmitAddAnother.Enabled = "False"
            End If
        End Sub

        Private Sub CheckEditPermissions()

            If Me.UserId = intUserID Or PortalSecurity.IsInRole("VCLink Moderator") _
            Or PortalSecurity.IsInRole("Administrators") Then
                'User is allowed to Edit

                bSubmit.Visible = "False"
                bSubmitAddAnother.Visible = "False"
                bUpdate.Visible = "True"
                bDelete.Visible = "True"
            Else
                lblNoEdit.Text = "Sneaky! You do not have permission to edit this link"
                bSubmit.Visible = "False"
                bSubmitAddAnother.Visible = "False"
                bUpdate.Visible = "False"
                bDelete.Visible = "False"
            End If

        End Sub

        Private Sub PopulateFields()

            Try
                'Populate ddlCategory

                ' get Country object
                Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
                Dim objConn As New SqlConnection(strConn)
                Dim cmd As New SqlCommand

                cmd.CommandText = "vcLinks_GetLinkID"
                cmd.CommandType = CommandType.StoredProcedure
                cmd.Connection = objConn

                cmd.Parameters.AddWithValue("@VCLinksID", VCLinksID)

                'Create DataReader
                Dim drRequestInfo As SqlDataReader

                'Open Connection
                objConn.Open()

                'Populate DataReader
                drRequestInfo = cmd.ExecuteReader()

                While drRequestInfo.Read()
                    'reading from the datareader and setting controls

                    ddlCategory.SelectedValue = drRequestInfo("VCLinksCategoryID")
                    tbLinkName.Text = drRequestInfo("LinkName")
                    tbLinkURL.Text = drRequestInfo("LinkURL")
                    tbLinkDescription.Text = drRequestInfo("LinkDescription")
                    intUserID = drRequestInfo("SubmittedBy")

                End While

                drRequestInfo.Close()
                objConn.Close()

            Catch exc As Exception

            End Try
        End Sub

        Private Sub PopulateCat()
            'Populate ddlCategory

            ' get Country object
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinksCategory_GetCategories_All"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            objConn.Open()

            ddlCategory.DataSource = cmd.ExecuteReader
            ddlCategory.DataTextField = "CategoryName"
            ddlCategory.DataValueField = "VCLinksCategoryID"
            ddlCategory.DataBind()

            objConn.Close()

        End Sub

        Private Sub AddLink()
            'Go ahead and add restaurant
            'Set Labels and Textbox values to parameters

            Dim intCategory As Integer = ddlCategory.SelectedValue
            Dim strLinkName As String = tbLinkName.Text
            Dim strLinkURL As String = tbLinkURL.Text
            Dim strLinkDescription As String = tbLinkDescription.Text


            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_AddLink"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@intCategory", intCategory)
            cmd.Parameters.AddWithValue("@strLinkName", strLinkName)
            cmd.Parameters.AddWithValue("@strLinkURL", strLinkURL)
            cmd.Parameters.AddWithValue("@strLinkDescription", strLinkDescription)
            cmd.Parameters.AddWithValue("@intSubmittedBy", Me.UserId)
            cmd.Parameters.AddWithValue("@SubmittedDate", Date.Now.ToShortDateString)

            objConn.Open()

            'Get ID of Restaurant Just added 
            Dim intVCLinksID As Integer = cmd.ExecuteScalar

            objConn.Close()

        End Sub

        Private Sub DeleteLink()
            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_DeleteLink"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@intVCLinksID", VCLinksID)

            objConn.Open()

            'Get ID of Restaurant Just added 
            cmd.ExecuteNonQuery()

            objConn.Close()
        End Sub

        Private Sub UpdateLink()

            Dim intCategory As Integer = ddlCategory.SelectedValue
            Dim strLinkName As String = tbLinkName.Text
            Dim strLinkURL As String = tbLinkURL.Text
            Dim strLinkDescription As String = tbLinkDescription.Text


            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_UpdateLink"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@intVCLinksID", VCLinksID)
            cmd.Parameters.AddWithValue("@intCategory", intCategory)
            cmd.Parameters.AddWithValue("@strLinkName", strLinkName)
            cmd.Parameters.AddWithValue("@strLinkURL", strLinkURL)
            cmd.Parameters.AddWithValue("@strLinkDescription", strLinkDescription)
            cmd.Parameters.AddWithValue("@intUpdatedBy", Me.UserId)
            cmd.Parameters.AddWithValue("@UpdatedDate", Date.Now)

            objConn.Open()

            'Get ID of Restaurant Just added 
            cmd.ExecuteNonQuery()

            objConn.Close()

        End Sub



#End Region

#Region " Events "

        Protected Sub cvalLinkNameExist_ServerValidate(ByVal source As Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles cvalLinkNameExist.ServerValidate

            'Check to see if LinkName Already Exists

            Dim intExists As Integer

            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_Validate"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@ColumnNameValue", tbLinkName.Text)

            objConn.Open()

            'Get ID of Restaurant Just added 

            intExists = cmd.ExecuteScalar()

            objConn.Close()

            ReadQueryString()
            If VCLinksID > 0 Then
                args.IsValid = "True"
            Else

                If intExists > 0 Then
                    args.IsValid = "false"
                Else
                    args.IsValid = "true"
                End If
            End If

        End Sub

        Protected Sub cvalLinkURL_ServerValidate(ByVal source As Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles cvalLinkURL.ServerValidate


            'Check to see if LinkName Already Exists

            Dim intExists As Integer

            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_Validate"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@ColumnNameValue", tbLinkURL.Text)

            objConn.Open()

            'Get ID of Restaurant Just added 

            intExists = cmd.ExecuteScalar()

            objConn.Close()

            ReadQueryString()
            If VCLinksID > 0 Then
                args.IsValid = "True"
            Else

                If intExists > 0 Then
                    args.IsValid = "false"
                Else
                    args.IsValid = "true"
                End If
            End If

        End Sub

        Protected Sub cvalddlCategory_ServerValidate(ByVal source As Object, ByVal args As System.Web.UI.WebControls.ServerValidateEventArgs) Handles cvalddlCategory.ServerValidate
            If ddlCategory.SelectedIndex > 0 Then
                args.IsValid = "true"
            Else
                args.IsValid = "false"
            End If

        End Sub

        Protected Sub bSubmit_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bSubmit.Click
            Page.Validate("AddLink")
            If Page.IsValid Then
                AddLink()
                Response.Redirect(NavigateURL(), True)
            End If
        End Sub

        Protected Sub bSubmitAddAnother_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bSubmitAddAnother.Click
            Page.Validate("AddLink")
            If Page.IsValid Then
                AddLink()
            End If
            tbLinkURL.Text = ""
            lblNoEdit.Text = "Link Added!"
        End Sub

        Protected Sub bDelete_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bDelete.Click

            ReadQueryString()
            DeleteLink()
            lblNoEdit.Text = " Link Deleted!"
            bUpdate.Enabled = "False"
            bDelete.Enabled = "False"

        End Sub

        Protected Sub bUpdate_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bUpdate.Click
            Page.Validate("AddLink")
            If Page.IsValid Then
                ReadQueryString()
                UpdateLink()
                lblNoEdit.Text = " Link Updated!"
            End If

        End Sub

#End Region


    End Class
End Namespace
