
Imports DotNetNuke
Imports DotNetNuke.Common
Imports DotNetNuke.Entities.Modules
Imports System.Data.SqlClient

Namespace VinoCellar.Modules.VCLinks
    Partial Class ucLinkDetail
        Inherits Entities.Modules.PortalModuleBase

#Region " Private Members "

        Private VCLinksID As Integer
        Private intAddedByID As Integer

#End Region

#Region " Private Methods "

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try
                bReturn.Attributes.Add("onclick", "history.back()")

                If Page.IsPostBack = False Then
                    ReadQueryString()
                    If VCLinksID > 0 Then
                        'Since there is a linkid, we'll populate all fields
                        PopulateFields()
                        'See if user is a moderator or created link
                        'These users can edit the link.
                        CheckEditPermissions()
                        'Edit permissions might enable bApproveLink
                        'But it may not need approving, so disable it
                        If lblApproved.Text = "Link Approved" Then
                            bApproveLink.Enabled = "False"
                        End If

                    End If
                End If

            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub ReadQueryString()
            If (Request("LinkDetail") <> "") Then
                If (IsNumeric(Request("LinkDetail"))) Then
                    VCLinksID = CInt(Request.QueryString("LinkDetail"))
                End If
            Else
                VCLinksID = Null.NullInteger
            End If
        End Sub

        Private Sub CheckEditPermissions()

            If Me.UserInfo.IsInRole("VCLink Moderator") Or Me.UserInfo.IsInRole("Administrators") Then
                bEditLink.Visible = "True"
                bApproveLink.Visible = "True"
            Else
                If Me.UserId = intAddedByID Then
                    bEditLink.Visible = "True"
                    bApproveLink.Visible = "False"
                Else
                    'If UserID = -1 then user is anonymous and not logged in
                    If Me.UserId = -1 Then
                        bEditLink.Visible = "False"
                        bApproveLink.Visible = "False"
                    End If
                End If
            End If

        End Sub

        Private Sub PopulateFields()

            Try
                'Populate ddlCategory

                ' get Country object
                Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
                Dim objConn As New SqlConnection(strConn)
                Dim cmd As New SqlCommand

                cmd.CommandText = "vcLinks_GetLinkIDDetail"
                cmd.CommandType = CommandType.StoredProcedure
                cmd.Connection = objConn

                cmd.Parameters.AddWithValue("@VCLinksID", VCLinksID)

                'Create DataReader
                Dim drRequestInfo As SqlDataReader

                'Open Connection
                objConn.Open()

                'Populate DataReader
                drRequestInfo = cmd.ExecuteReader()

                While drRequestInfo.Read()
                    'reading from the datareader and setting controls

                    lblCategory.Text = drRequestInfo("Category")
                    lblLinkNameTitle.Text = "<H2>" + drRequestInfo("LinkName") + "</H3>"
                    lblLinkName.Text = drRequestInfo("LinkName")
                    hlLinkURL.Text = drRequestInfo("LinkURL")
                    hlLinkURL.NavigateUrl = drRequestInfo("LinkURL")
                    hlLinkURL.ToolTip = drRequestInfo("LinkURL")
                    lblLinkDescription.Text = drRequestInfo("LinkDescription")
                    lblAddedOn.Text = drRequestInfo("AddedOn")
                    lblAddedBy.Text = drRequestInfo("AddedBy")
                    If drRequestInfo("Approved") Is DBNull.Value Then
                        lblApproved.Text = "Not Approved Yet"
                    Else
                        If drRequestInfo("Approved") = 0 Then
                            lblApproved.Text = "Not Approved Yet"
                        Else
                            If drRequestInfo("Approved") = 1 Then
                                lblApproved.Text = "Link Approved"
                            End If
                        End If
                    End If
                    'Let's set the ID of user who added link so we can check permissions later
                    intAddedByID = drRequestInfo("AddedByID")

                End While

                drRequestInfo.Close()
                objConn.Close()

            Catch exc As Exception

            End Try
        End Sub

        Private Sub ApproveLink()

            'Set link to "approved" status
            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_ApproveLink"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@intVCLinksID", VCLinksID)
            cmd.Parameters.AddWithValue("@intUserID", Me.UserId)
            cmd.Parameters.AddWithValue("@DateNow", Date.Today)

            objConn.Open()

            'Get ID of Restaurant Just added 
            Dim intRowsAffected As Integer = cmd.ExecuteNonQuery

            objConn.Close()

            If intRowsAffected = 1 Then
                lblApproved.Text = "Link Approved"
                lblApproved.ForeColor = Color.Red
            Else
                lblApproved.Text = "Something went wrong, please let Administrator know."
                lblApproved.ForeColor = Color.Red
            End If

        End Sub

#End Region

#Region " Events "

#End Region

        Protected Sub bApproveLink_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bApproveLink.Click
            ReadQueryString()
            ApproveLink()
            bApproveLink.Enabled = "False"

        End Sub

        Protected Sub bEditLink_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bEditLink.Click

            'Get the LinkID to pass
            ReadQueryString()
            'This user has Edit permissions, so let's go to the edit page (addlink)
            Response.Redirect(Globals.NavigateURL(Me.TabId, Null.NullString, "LinkID=" & VCLinksID), True)

        End Sub
    End Class
End Namespace

